@@ -22,7 +22,7 @@ excel_dict = {"fake2excel": "https://www.bilibili.com/video/BV1wr4y1b7uk",
               "merge2sheet": "",
               "sheet2excel": "https://mp.weixin.qq.com/s/dAx6JEbj5OlVnCcxokCzTQ",
               "split_excel_by_column": "",
-              "excel2pdf": "https://www.zhihu.com/question/303009968/answer/2926093618",
+              "excel2pdf": "https://mp.weixin.qq.com/s/9cobekrIrR7BnUzfepv6Tg",
               }
 image_dict = {"add_watermark": "https://www.bilibili.com/video/BV1jT411T7n9",
               "decode_qrcode": "https://mp.weixin.qq.com/s/Z_RcTRYxUFpCQBGpShO0ig",
@@ -36,7 +36,7 @@ md_dict = {}
 ocr_dict = {}
 pdf_dict = {"add_img_water": "",
             "add_watermark": "https://www.bilibili.com/video/BV1Se411T7au",
-            "add_watermark_by_parameters": "",
+            "add_watermark_by_parameters": "https://www.bilibili.com/video/BV1Se411T7au",
             "decrypt4pdf": "https://mp.weixin.qq.com/s/GiXYB_xZdlsYv5AIeIELkA",
             "encrypt4pdf": "https://mp.weixin.qq.com/s/GiXYB_xZdlsYv5AIeIELkA",
             "merge2pdf": "https://mp.weixin.qq.com/s/9erh3W3WCD36Axj70pRvog",
@@ -67,7 +67,7 @@ wechat_dict = {"chat_by_keywords": "https://www.bilibili.com/video/BV1fV4y1M7ju"
                "send_message_by_time": "https://www.bilibili.com/video/BV1m8411b7LZ", }
 word_dict = {
     "docx2pdf": "https://mp.weixin.qq.com/s/eBn3N_FEx1dlC_-ttmlOwg",
-    "merge4docx": "http://www.python4office.cn/python-office/merge4docx/",
+    "merge4docx": "https://www.bilibili.com/video/BV1Vo4y1q7i3",
              }
 
 file_dict = {"search_by_content": "https://mp.weixin.qq.com/s/rvU7O3zHJ-YEd2YU0Z4pew",
@@ -78,7 +78,7 @@ file_dict = {"search_by_content": "https://mp.weixin.qq.com/s/rvU7O3zHJ-YEd2YU0Z
              "output_file_list_to_excel": "",
              "replace4filename": "https://www.bilibili.com/video/BV12r4y187Yj",
              "search_specify_type_file": "",
-             "group_by_name": "https://www.zhihu.com/question/34633472/answer/2936506900",
+             "group_by_name": "https://www.bilibili.com/video/BV1RX4y1o7HF",
              }
 
 # 有多少文件需要说明
